clear all
use "short_census92_JHR_reg.dta"


**************************
* define dummy variables *
**************************

**** ethnicity ***
forvalues ethnic=1/4 {
   quietly gen byte ethnic_`ethnic'=0 if ethnic!=.
   quietly replace ethnic_`ethnic'=1 if ethnic==`ethnic'
}


**** discontinuity *****
forvalues disc=44/53 {
   quietly gen byte disc_`disc'=0 if disc!=.
   quietly replace disc_`disc'=1 if disc==`disc'
}



******************
* define density *
******************

gen byte ones=1
bys day1 disc: egen freq=total(ones)
bys disc: egen denom=total(ones)
gen density=freq/denom


**********************
* collapse full data *
**********************

collapse density s_years_schooling s_primary years_schooling primary_none lower_sec upper_sec uni employed active children skill1 female ethnic_1 ethnic_2 ethnic_3 ethnic_4 urban buc disc_* after treatment after_treatment day1_* day2* day3* (count) n=ones, by(day1 disc)



******************** define macros *************

global trend "day1 day1_after" 

global controls1 "female urban ethnic_* region_* disc_*"
global controls1 ""

global restrict1 1
global restrict2 1

global trend "day1" 




******************************************************** Figure 3: Years of schooling ***********************************************************


******************** day of birth ******************

****** treatment group *******

preserve


********************
keep if treatment==1
********************

*** generate binned categories

global step "1"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse years_schooling (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen years_schooling_donut7=years_schooling if day1_cat<=6 & day1_cat>=-7
gen years_schooling_donut14=years_schooling if (day1_cat>=6 & day1_cat<=13) | (day1_cat>=-14 & day1_cat<=-7)
gen years_schooling_nodonut=years_schooling if day1_cat>=14 | day1_cat<=-15

reg years_schooling $trend if day1<0, robust
predict years_schoolingY_A if e(sample)
reg years_schooling $trend if day1>=0, robust
predict years_schoolingY_B if e(sample)

reg years_schooling $trend if day1<-7, robust
predict years_schoolingY_A_donut7 if e(sample)
reg years_schooling $trend if day1>=7, robust
predict years_schoolingY_B_donut7 if e(sample)




#delimit;

scatter years_schooling_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter years_schooling_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter years_schooling_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line years_schoolingY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line years_schoolingY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line years_schoolingY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line years_schoolingY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-180 0 180)
 xscale(range(-180 0 180))
 ylabel(9 11)
 title(Panel A: Treatment, position(11) size(medsmall))
 ytitle(density, size(small))
 xtitle(day of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("years_schooling_treat_day",replace);

#delimit cr;


****** control group *******

restore
preserve

********************
keep if treatment==0
********************


*** generate binned categories

global step "1"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step

collapse years_schooling (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen years_schooling_donut7=years_schooling if day1_cat<=6 & day1_cat>=-7
gen years_schooling_donut14=years_schooling if (day1_cat>=6 & day1_cat<=13) | (day1_cat>=-14 & day1_cat<=-7)
gen years_schooling_nodonut=years_schooling if day1_cat>=14 | day1_cat<=-15

reg years_schooling $trend if day1<0, robust
predict years_schoolingY_A if e(sample)
reg years_schooling $trend if day1>=0, robust
predict years_schoolingY_B if e(sample)



reg years_schooling $trend if day1<-7, robust
predict years_schoolingY_A_donut7 if e(sample)
reg years_schooling $trend if day1>=7, robust
predict years_schoolingY_B_donut7 if e(sample)



#delimit;

scatter years_schooling_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter years_schooling_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter years_schooling_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line years_schoolingY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line years_schoolingY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line years_schoolingY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line years_schoolingY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-180 0 180)
 xscale(range(-180 0 180))
 ylabel(9 11)
 title(Panel C: Control, position(11) size(medsmall))
 ytitle(Years of schooling, size(small))
 xtitle(day of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("years_schooling_controls_day",replace);


#delimit cr;


****** treatment-control differences *******

restore
preserve

drop if treatment==.

collapse years_schooling, by(day1 treatment)
gen int id=_n
reshape wide years_schooling , i(id) j(treatment)
collapse years_schooling1 years_schooling0 , by(day1)
gen years_schooling=years_schooling1-years_schooling0


gen day2=day1*day1
gen day3=day1*day1*day1


*** generate binned categories

global step "1"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step

collapse years_schooling (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


reg years_schooling $trend if day1<0, robust
predict years_schoolingY_A if e(sample)
reg years_schooling $trend if day1>=0, robust
predict years_schoolingY_B if e(sample)


reg years_schooling $trend if day1<-7, robust
predict years_schoolingY_A_donut7 if e(sample)
reg years_schooling $trend if day1>=7, robust
predict years_schoolingY_B_donut7 if e(sample)


gen years_schooling_donut7=years_schooling if day1_cat<=6 & day1_cat>=-7
gen years_schooling_donut14=years_schooling if (day1_cat>=6 & day1_cat<=13) | (day1_cat>=-14 & day1_cat<=-7)
gen years_schooling_nodonut=years_schooling if day1_cat>=14 | day1_cat<=-15




#delimit;

scatter years_schooling_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter years_schooling_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter years_schooling_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line years_schoolingY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line years_schoolingY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line years_schoolingY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line years_schoolingY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-180 0 180)
 xscale(range(-180 0 180))
 ylabel(-1.5 0.5)
 title(Panel E: Treatment-Control, position(11) size(medsmall))
 ytitle(Years of schooling, size(small))
 xtitle(day of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("years_schooling_diff_day",replace);


#delimit cr;




******************** week of birth ******************

restore
preserve

****** treatment group *******

********************
keep if treatment==1
********************

*** generate predicted values for fitted lines

reg years_schooling $trend if day1<0, robust
predict years_schoolingY_A if e(sample)
reg years_schooling $trend if day1>=0, robust
predict years_schoolingY_B if e(sample)


reg years_schooling $trend if day1<-7, robust
predict years_schoolingY_A_donut7 if e(sample)
reg years_schooling $trend if day1>=7, robust
predict years_schoolingY_B_donut7 if e(sample)



*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse years_schooling years_schoolingY_A years_schoolingY_B years_schoolingY_A_donut7 years_schoolingY_B_donut7 (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)



gen years_schooling_donut7=years_schooling if day1_cat==-1 | day1_cat==0
gen years_schooling_donut14=years_schooling if day1_cat==-2 | day1_cat==1
gen years_schooling_nodonut=years_schooling if day1_cat>=2 | day1_cat<=-3



#delimit;

scatter years_schooling_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter years_schooling_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter years_schooling_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line years_schoolingY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line years_schoolingY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line years_schoolingY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line years_schoolingY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(9 11)
 title(Panel B: Treatment, position(11) size(medsmall))
 ytitle(Years of schooling, size(small))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("years_schooling_treat_week",replace);


#delimit cr;


****** control group *******

restore
preserve

********************
keep if treatment==0
********************

reg years_schooling $trend if day1<0, robust
predict years_schoolingY_A if e(sample)
reg years_schooling $trend if day1>=0, robust
predict years_schoolingY_B if e(sample)

reg years_schooling $trend if day1<-7, robust
predict years_schoolingY_A_donut7 if e(sample)
reg years_schooling $trend if day1>=7, robust
predict years_schoolingY_B_donut7 if e(sample)


*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse years_schooling years_schoolingY_A years_schoolingY_B years_schoolingY_A_donut7 years_schoolingY_B_donut7 (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen years_schooling_donut7=years_schooling if day1_cat==-1 | day1_cat==0
gen years_schooling_donut14=years_schooling if day1_cat==-2 | day1_cat==1
gen years_schooling_nodonut=years_schooling if day1_cat>=2 | day1_cat<=-3

#delimit;

scatter years_schooling_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter years_schooling_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter years_schooling_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line years_schoolingY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line years_schoolingY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line years_schoolingY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line years_schoolingY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(9 11)
 title(Panel D: Control, position(11) size(medsmall))
 ytitle(Years of schooling, size(small))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("years_schooling_controls_week",replace);



#delimit cr;


****** treatment-control differences *******

restore
preserve

drop if treatment==.

collapse years_schooling , by(day1 treatment)
gen int id=_n
reshape wide years_schooling , i(id) j(treatment)
collapse years_schooling1 years_schooling0 , by(day1)
gen years_schooling=years_schooling1-years_schooling0


gen day2=day1*day1
gen day3=day1*day1*day1

reg years_schooling $trend if day1<0, robust
predict years_schoolingY_A if e(sample)
reg years_schooling $trend if day1>=0, robust
predict years_schoolingY_B if e(sample)

reg years_schooling $trend if day1<-7, robust
predict years_schoolingY_A_donut7 if e(sample)
reg years_schooling $trend if day1>=7, robust
predict years_schoolingY_B_donut7 if e(sample)



*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse years_schooling years_schoolingY_A years_schoolingY_B years_schoolingY_A_donut7 years_schoolingY_B_donut7 (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen years_schooling_donut7=years_schooling if day1_cat==-1 | day1_cat==0
gen years_schooling_donut14=years_schooling if day1_cat==-2 | day1_cat==1
gen years_schooling_nodonut=years_schooling if day1_cat>=2 | day1_cat<=-3



#delimit;

scatter years_schooling_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter years_schooling_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter years_schooling_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line years_schoolingY_A day1_cat,
 clcolor(gs10)
 clwidth(thick)
 clpattern(solid)
 || line years_schoolingY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line years_schoolingY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(medium)
 clpattern(solid)
 || line years_schoolingY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(-1.5 0.5)
 title(Panel F: Treatment-Control, position(11) size(medsmall))
 ytitle(Years of schooling, size(small))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("years_schooling_diff_week",replace);


#delimit cr;


graph combine years_schooling_treat_day.gph years_schooling_treat_week.gph years_schooling_controls_day.gph years_schooling_controls_week.gph years_schooling_diff_day.gph years_schooling_diff_week.gph, ysize(9) holes(3 6 9) scheme(s1color) saving("Figure3",replace)

erase years_schooling_treat_week.gph
erase years_schooling_controls_week.gph
erase years_schooling_diff_week.gph
erase years_schooling_treat_day.gph
erase years_schooling_controls_day.gph
erase years_schooling_diff_day.gph






********************************************************* Appendix Figure 2: Density ***********************************************************



******************** day of birth ******************

****** treatment group *******

restore
preserve


********************
keep if treatment==1
********************

*** generate binned categories

global step "1"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse density (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen density_donut7=density if day1_cat<=6 & day1_cat>=-7
gen density_donut14=density if (day1_cat>=6 & day1_cat<=13) | (day1_cat>=-14 & day1_cat<=-7)
gen density_nodonut=density if day1_cat>=14 | day1_cat<=-15

reg density $trend if day1<0, robust
predict densityY_A if e(sample)
reg density $trend if day1>=0, robust
predict densityY_B if e(sample)

reg density $trend if day1<-7, robust
predict densityY_A_donut7 if e(sample)
reg density $trend if day1>=7, robust
predict densityY_B_donut7 if e(sample)




#delimit;

scatter density_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter density_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter density_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line densityY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line densityY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line densityY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line densityY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-180 0 180)
 xscale(range(-180 0 180))
 ylabel(0 .01)
 title(Panel A: Treatment, position(11) size(medsmall))
 ytitle(Years of schooling, size(small))
 xtitle(day of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("density_treat_day",replace);

#delimit cr;


****** control group *******

restore
preserve

********************
keep if treatment==0
********************


*** generate binned categories

global step "1"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step

collapse density (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen density_donut7=density if day1_cat<=6 & day1_cat>=-7
gen density_donut14=density if (day1_cat>=6 & day1_cat<=13) | (day1_cat>=-14 & day1_cat<=-7)
gen density_nodonut=density if day1_cat>=14 | day1_cat<=-15

reg density $trend if day1<0, robust
predict densityY_A if e(sample)
reg density $trend if day1>=0, robust
predict densityY_B if e(sample)



reg density $trend if day1<-7, robust
predict densityY_A_donut7 if e(sample)
reg density $trend if day1>=7, robust
predict densityY_B_donut7 if e(sample)



#delimit;

scatter density_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter density_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter density_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line densityY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line densityY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line densityY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line densityY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-180 0 180)
 xscale(range(-180 0 180))
 ylabel(0 .01)
 title(Panel C: Control, position(11) size(medsmall))
 ytitle(density, size(small))
 xtitle(day of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("density_controls_day",replace);


#delimit cr;


****** treatment-control differences *******

restore
preserve

drop if treatment==.

collapse density, by(day1 treatment)
gen int id=_n
reshape wide density , i(id) j(treatment)
collapse density1 density0 , by(day1)
gen density=density1-density0


gen day2=day1*day1
gen day3=day1*day1*day1


*** generate binned categories

global step "1"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step

collapse density (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


reg density $trend if day1<0, robust
predict densityY_A if e(sample)
reg density $trend if day1>=0, robust
predict densityY_B if e(sample)


reg density $trend if day1<-7, robust
predict densityY_A_donut7 if e(sample)
reg density $trend if day1>=7, robust
predict densityY_B_donut7 if e(sample)


gen density_donut7=density if day1_cat<=6 & day1_cat>=-7
gen density_donut14=density if (day1_cat>=6 & day1_cat<=13) | (day1_cat>=-14 & day1_cat<=-7)
gen density_nodonut=density if day1_cat>=14 | day1_cat<=-15




#delimit;

scatter density_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter density_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter density_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line densityY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line densityY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line densityY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line densityY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-180 0 180)
 xscale(range(-180 0 180))
 ylabel(-.001 .001)
 title(Panel E: Treatment-Control, position(11) size(medsmall))
 ytitle(density, size(small))
 xtitle(day of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("density_diff_day",replace);


#delimit cr;




******************** week of birth ******************

restore
preserve

****** treatment group *******

********************
keep if treatment==1
********************

*** generate predicted values for fitted lines

reg density $trend if day1<0, robust
predict densityY_A if e(sample)
reg density $trend if day1>=0, robust
predict densityY_B if e(sample)


reg density $trend if day1<-7, robust
predict densityY_A_donut7 if e(sample)
reg density $trend if day1>=7, robust
predict densityY_B_donut7 if e(sample)



*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse density densityY_A densityY_B densityY_A_donut7 densityY_B_donut7 (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)



gen density_donut7=density if day1_cat==-1 | day1_cat==0
gen density_donut14=density if day1_cat==-2 | day1_cat==1
gen density_nodonut=density if day1_cat>=2 | day1_cat<=-3



#delimit;

scatter density_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter density_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter density_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line densityY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line densityY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line densityY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line densityY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(0 .01)
 title(Panel B: Treatment, position(11) size(medsmall))
 ytitle(density, size(small))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("density_treat_week",replace);


#delimit cr;


****** control group *******

restore
preserve

********************
keep if treatment==0
********************

reg density $trend if day1<0, robust
predict densityY_A if e(sample)
reg density $trend if day1>=0, robust
predict densityY_B if e(sample)

reg density $trend if day1<-7, robust
predict densityY_A_donut7 if e(sample)
reg density $trend if day1>=7, robust
predict densityY_B_donut7 if e(sample)


*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse density densityY_A densityY_B densityY_A_donut7 densityY_B_donut7 (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen density_donut7=density if day1_cat==-1 | day1_cat==0
gen density_donut14=density if day1_cat==-2 | day1_cat==1
gen density_nodonut=density if day1_cat>=2 | day1_cat<=-3

#delimit;

scatter density_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter density_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter density_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line densityY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line densityY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line densityY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line densityY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(0 .01)
 title(Panel D: Control, position(11) size(medsmall))
 ytitle(density, size(small))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("density_controls_week",replace);



#delimit cr;


****** treatment-control differences *******

restore
preserve

drop if treatment==.

collapse density , by(day1 treatment)
gen int id=_n
reshape wide density , i(id) j(treatment)
collapse density1 density0 , by(day1)
gen density=density1-density0


gen day2=day1*day1
gen day3=day1*day1*day1

reg density $trend if day1<0, robust
predict densityY_A if e(sample)
reg density $trend if day1>=0, robust
predict densityY_B if e(sample)

reg density $trend if day1<-7, robust
predict densityY_A_donut7 if e(sample)
reg density $trend if day1>=7, robust
predict densityY_B_donut7 if e(sample)



*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse density densityY_A densityY_B densityY_A_donut7 densityY_B_donut7 (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen density_donut7=density if day1_cat==-1 | day1_cat==0
gen density_donut14=density if day1_cat==-2 | day1_cat==1
gen density_nodonut=density if day1_cat>=2 | day1_cat<=-3



#delimit;

scatter density_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter density_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter density_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line densityY_A day1_cat,
 clcolor(gs10)
 clwidth(thick)
 clpattern(solid)
 || line densityY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line densityY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(medium)
 clpattern(solid)
 || line densityY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(-.001 .001)
 title(Panel F: Treatment-Control, position(11) size(medsmall))
 ytitle(density, size(small))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("density_diff_week",replace);


#delimit cr;


graph combine density_treat_day.gph density_treat_week.gph density_controls_day.gph density_controls_week.gph density_diff_day.gph density_diff_week.gph, ysize(9) holes(3 6 9) scheme(s1color) saving("AppendixFigure2",replace)

erase density_treat_week.gph
erase density_controls_week.gph
erase density_diff_week.gph
erase density_treat_day.gph
erase density_controls_day.gph
erase density_diff_day.gph





***************************************************** Appendix Figure 3: Educational categories *****************************************************

restore
preserve

*** collapse data to generate treatment-control

collapse primary_none uni lower_sec upper_sec, by(day1 treatment)
gen int id=_n
reshape wide primary_none lower_sec upper_sec uni , i(id) j(treatment)
collapse primary_none1 lower_sec1 upper_sec1 uni1 primary_none0 lower_sec0 upper_sec0 uni0 , by(day1)
gen primary_none=primary_none1-primary_none0
gen lower_sec=lower_sec1-lower_sec0
gen upper_sec=upper_sec1-upper_sec0
gen uni=uni1-uni0


gen day2=day1*day1
gen day3=day1*day1*day1


*** predict trend lines


reg primary_none $trend if day1<0, robust
predict primary_noneY_A if e(sample)
reg primary_none $trend if day1>0, robust
predict primary_noneY_B if e(sample)

reg lower_sec $trend if day1<0, robust
predict lower_secY_A if e(sample)
reg lower_sec $trend if day1>0, robust
predict lower_secY_B if e(sample)

reg upper_sec $trend if day1<0, robust
predict upper_secY_A if e(sample)
reg upper_sec $trend if day1>0, robust
predict upper_secY_B if e(sample)

reg uni $trend if day1<0, robust
predict uniY_A if e(sample)
reg uni $trend if day1>0, robust
predict uniY_B if e(sample)



reg primary_none $trend if day1<-7, robust
predict primary_noneY_A_donut7 if e(sample)
reg primary_none $trend if day1>=7, robust
predict primary_noneY_B_donut7 if e(sample)

reg lower_sec $trend if day1<-7, robust
predict lower_secY_A_donut7 if e(sample)
reg lower_sec $trend if day1>=7, robust
predict lower_secY_B_donut7 if e(sample)

reg upper_sec $trend if day1<-7, robust
predict upper_secY_A_donut7 if e(sample)
reg upper_sec $trend if day1>=7, robust
predict upper_secY_B_donut7 if e(sample)

reg uni $trend if day1<-7, robust
predict uniY_A_donut7 if e(sample)
reg uni $trend if day1>=7, robust
predict uniY_B_donut7 if e(sample)



*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


*** collapse to the week level

collapse primary_none primary_noneY_A primary_noneY_B lower_sec lower_secY_A lower_secY_B upper_sec upper_secY_A upper_secY_B uni uniY_A uniY_B primary_noneY_A_donut7 primary_noneY_B_donut7 lower_secY_A_donut7 lower_secY_B_donut7 upper_secY_A_donut7 upper_secY_B_donut7 uniY_A_donut7 uniY_B_donut7 (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen primary_none_donut7=primary_none if day1_cat==-1 | day1_cat==0
gen primary_none_donut14=primary_none if day1_cat==-2 | day1_cat==1
gen primary_none_nodonut=primary_none if day1_cat>=2 | day1_cat<=-3

gen lower_sec_donut7=lower_sec if day1_cat==-1 | day1_cat==0
gen lower_sec_donut14=lower_sec if day1_cat==-2 | day1_cat==1
gen lower_sec_nodonut=lower_sec if day1_cat>=2 | day1_cat<=-3

gen upper_sec_donut7=upper_sec if day1_cat==-1 | day1_cat==0
gen upper_sec_donut14=upper_sec if day1_cat==-2 | day1_cat==1
gen upper_sec_nodonut=upper_sec if day1_cat>=2 | day1_cat<=-3

gen uni_donut7=uni if day1_cat==-1 | day1_cat==0
gen uni_donut14=uni if day1_cat==-2 | day1_cat==1
gen uni_nodonut=uni if day1_cat>=2 | day1_cat<=-3




#delimit;


scatter primary_none_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(black black)
 sort
 || scatter primary_none_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter primary_none_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line primary_noneY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line primary_noneY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line primary_noneY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line primary_noneY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(0 0.2)
 title(Panel A: Primary, position(11) size(medsmall))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("primary_none_diff_week",replace);



scatter lower_sec_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(black black)
 sort
 || scatter lower_sec_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter lower_sec_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line lower_secY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line lower_secY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line lower_secY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line lower_secY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(-0.1 0.1)
 title(Panel B: Lower secondary, position(11) size(medsmall))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("lower_sec_diff_week",replace);



scatter upper_sec_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(black black)
 sort
 || scatter upper_sec_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter upper_sec_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line upper_secY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line upper_secY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line upper_secY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line upper_secY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(-0.2 0)
 title(Panel C: Upper secondary, position(11) size(medsmall))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("upper_sec_diff_week",replace);



scatter uni_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(black black)
 sort
 || scatter uni_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter uni_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line uniY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line uniY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line uniY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line uniY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(-0.1 0.1)
 title(Panel D: Higher education, position(11) size(medsmall))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("uni_diff_week",replace);



#delimit cr;


graph combine primary_none_diff_week.gph lower_sec_diff_week.gph upper_sec_diff_week.gph uni_diff_week.gph , ysize(6) holes(3 6) scheme(s1color) saving("AppendixFigure3",replace)



erase primary_none_diff_week.gph
erase lower_sec_diff_week.gph
erase upper_sec_diff_week.gph
erase uni_diff_week.gph



***************************************************** Appendix Figure 4: Socio-economic outcomes *****************************************************

restore
preserve

*** collapse data to generate treatment-control

collapse employed skill1 children s_years_schooling, by(day1 treatment)
gen int id=_n
reshape wide skill1 employed children s_years_schooling, i(id) j(treatment)
collapse employed1 skill11 children1 s_years_schooling1 employed0 skill10 children0 s_years_schooling0, by(day1)

gen employed=employed1-employed0
gen skill1=skill11-skill10
gen children=children1-children0
gen s_years_schooling=s_years_schooling1-s_years_schooling0


gen day2=day1*day1
gen day3=day1*day1*day1


*** predict trend lines

reg employed $trend if day1<0, robust
predict employedY_A if e(sample)
reg employed $trend if day1>0, robust
predict employedY_B if e(sample)

reg skill1 $trend if day1<0, robust
predict skill1Y_A if e(sample)
reg skill1 $trend if day1>0, robust
predict skill1Y_B if e(sample)

reg children $trend if day1<0, robust
predict childrenY_A if e(sample)
reg children $trend if day1>0, robust
predict childrenY_B if e(sample)

reg s_years_schooling $trend if day1<0, robust
predict s_years_schoolingY_A if e(sample)
reg s_years_schooling $trend if day1>0, robust
predict s_years_schoolingY_B if e(sample)


reg employed $trend if day1<-7, robust
predict employedY_A_donut7 if e(sample)
reg employed $trend if day1>=7, robust
predict employedY_B_donut7 if e(sample)

reg skill1 $trend if day1<-7, robust
predict skill1Y_A_donut7 if e(sample)
reg skill1 $trend if day1>=7, robust
predict skill1Y_B_donut7 if e(sample)

reg children $trend if day1<-7, robust
predict childrenY_A_donut7 if e(sample)
reg children $trend if day1>=7, robust
predict childrenY_B_donut7 if e(sample)

reg s_years_schooling $trend if day1<-7, robust
predict s_years_schoolingY_A_donut7 if e(sample)
reg s_years_schooling $trend if day1>=7, robust
predict s_years_schoolingY_B_donut7 if e(sample)


*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


*** collapse to the week level

collapse employed employedY_A employedY_B skill1 skill1Y_A skill1Y_B children childrenY_A childrenY_B s_years_schooling s_years_schoolingY_A s_years_schoolingY_B employedY_A_donut7 employedY_B_donut7 skill1Y_A_donut7 skill1Y_B_donut7 childrenY_A_donut7 childrenY_B_donut7 s_years_schoolingY_A_donut7 s_years_schoolingY_B_donut7 (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)

gen employed_donut7=employed if day1_cat==-1 | day1_cat==0
gen employed_donut14=employed if day1_cat==-2 | day1_cat==1
gen employed_nodonut=employed if day1_cat>=2 | day1_cat<=-3

gen skill1_donut7=skill1 if day1_cat==-1 | day1_cat==0
gen skill1_donut14=skill1 if day1_cat==-2 | day1_cat==1
gen skill1_nodonut=skill1 if day1_cat>=2 | day1_cat<=-3

gen children_donut7=children if day1_cat==-1 | day1_cat==0
gen children_donut14=children if day1_cat==-2 | day1_cat==1
gen children_nodonut=children if day1_cat>=2 | day1_cat<=-3

gen s_years_schooling_donut7=s_years_schooling if day1_cat==-1 | day1_cat==0
gen s_years_schooling_donut14=s_years_schooling if day1_cat==-2 | day1_cat==1
gen s_years_schooling_nodonut=s_years_schooling if day1_cat>=2 | day1_cat<=-3



******************** treatment-control differences ******************


#delimit;


scatter employed_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(black black)
 sort
 || scatter employed_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter employed_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line employedY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line employedY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line employedY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line employedY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(-0.05 0)
 title(Panel A: Employed, position(11) size(medsmall))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("employed_diff_week",replace);



scatter skill1_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(black black)
 sort
 || scatter skill1_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter skill1_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line skill1Y_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line skill1Y_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line skill1Y_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line skill1Y_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(-0.1 0.1)
 title(Panel B: Occupational skill, position(11) size(medsmall))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("skill1_diff_week",replace);



scatter children_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(black black)
 sort
 || scatter children_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter children_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line childrenY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line childrenY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line childrenY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line childrenY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(0 0.2)
 title(Panel C: Number of children, position(11) size(medsmall))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("children_diff_week",replace);



scatter s_years_schooling_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(black black)
 sort
 || scatter s_years_schooling_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter s_years_schooling_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line s_years_schoolingY_A day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line s_years_schoolingY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(dash)
 || line s_years_schoolingY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 || line s_years_schoolingY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(-1 -0.5)
 title(Panel D: Spousal schooling, position(11) size(medsmall))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("s_years_schooling_diff_week",replace);



#delimit cr;


graph combine employed_diff_week.gph skill1_diff_week.gph children_diff_week.gph s_years_schooling_diff_week.gph , ysize(6) holes(3 6) scheme(s1color) saving("AppendixFigure4",replace)


erase employed_diff_week.gph
erase skill1_diff_week.gph
erase children_diff_week.gph
erase s_years_schooling_diff_week.gph



