clear all

cd "/Users/kiki/Dropbox/Romania Education/JHR_replication_folder"
use short_census11.dta

*********
* setup *
*********

gen int month1=bmonth if bmonth<=6
replace month1=bmonth-12 if bmonth>6
gen int day1=bday if bday<=182
replace day1=bday-365 if bday>182
gen byte after=(month1>0)


gen int disc=.
replace disc=41 if (byear==1941 & after==0) | (byear==1942 & after==1) 
replace disc=42 if (byear==1942 & after==0) | (byear==1943 & after==1) 
replace disc=43 if (byear==1943 & after==0) | (byear==1944 & after==1) 
replace disc=44 if (byear==1944 & after==0) | (byear==1945 & after==1) 
replace disc=45 if (byear==1945 & after==0) | (byear==1946 & after==1) 
replace disc=46 if (byear==1946 & after==0) | (byear==1947 & after==1) 
replace disc=47 if (byear==1947 & after==0) | (byear==1948 & after==1) 
replace disc=48 if (byear==1948 & after==0) | (byear==1949 & after==1) 
replace disc=49 if (byear==1949 & after==0) | (byear==1950 & after==1) 
replace disc=50 if (byear==1950 & after==0) | (byear==1951 & after==1) 
replace disc=51 if (byear==1951 & after==0) | (byear==1952 & after==1) 
replace disc=52 if (byear==1952 & after==0) | (byear==1953 & after==1) 
replace disc=53 if (byear==1953 & after==0) | (byear==1954 & after==1) 
replace disc=54 if (byear==1954 & after==0) | (byear==1955 & after==1) 
replace disc=55 if (byear==1955 & after==0) | (byear==1956 & after==1)

gen byte treatment=.
replace treatment=1 if (disc>=44 & disc<=49)
replace treatment=0 if (disc>=50 & disc<=52)

gen byte after_treatment=after*treatment
gen byte control=1-treatment

***** day trends
gen day1_after=day1*after
gen day1_treatment=day1*treatment
gen day1_treatment_after=day1*treatment*after


**** discontinuity *****
forvalues disc=41/55 {
   quietly gen byte disc_`disc'=0 if disc!=.
   quietly replace disc_`disc'=1 if disc==`disc'
}

**** define day
gen day=byear*1000+bday

************************************ graphs *****************************************


gen wij=.
global trend "day1" 
global controls1 ""
global restrict1 1
global restrict2 1

***************************************************** week of birth *****************************************************

preserve

drop if treatment==.

collapse health , by(day1 treatment)
gen int id=_n
reshape wide health , i(id) j(treatment)
collapse health1  health0 , by(day1)
gen health=health1-health0


reg health $trend if day1<0, robust
predict healthY_A if e(sample)
reg health $trend if day1>=0, robust
predict healthY_B if e(sample)

reg health $trend if day1<-7, robust
predict healthY_A_donut7 if e(sample)
reg health $trend if day1>=7, robust
predict healthY_B_donut7 if e(sample)

*** generate binned categories

global step "7"
global end=$step*ceil(182/$step)
global cutwidthA "0($step)$end"
global cutwidthB "-$end($step)1"

egen day1_catA=cut(day1) if day1>=0, at($cutwidthA)
egen day1_catB=cut(day1) if day1<0, at($cutwidthB)

gen day1_cat=day1_catA
replace day1_cat=day1_catB if day1_cat==.
replace day1_cat=(day1_cat)/$step


collapse health healthY_A healthY_B  healthY_A_donut7 healthY_B_donut7   (max) max_day1=day1 (min) min_day1=day1 , by(day1_cat)


gen health_donut7=health if day1_cat==-1 | day1_cat==0
gen health_donut14=health if day1_cat==-2 | day1_cat==1
gen health_nodonut=health if day1_cat>=2 | day1_cat<=-3



#delimit;

scatter health_nodonut day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs3 gs3)
 sort
 || scatter health_donut7 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs13 gs13)
 sort
 || scatter health_donut14 day1_cat , 
 msymbol(Oh Oh)
 msize(small small)
 mcolor(gs7 gs7)
 sort
 || line healthY_A day1_cat,
 clcolor(gs10)
 clwidth(thick)
 clpattern(solid)
 || line healthY_B day1_cat,
 clcolor(gs10)
 clwidth(medium)
 clpattern(solid)
 || line healthY_A_donut7 day1_cat,
 clcolor(black)
 clwidth(medium)
 clpattern(solid)
 || line healthY_B_donut7 day1_cat,
 clcolor(black)
 clwidth(thick)
 clpattern(solid)
 legend(off)
 xlabel(-26 0 26)
 xscale(range(-26 0 26))
 ylabel(-.05 .05)
 title(Panel B: Self-reported health, position(11) size(medsmall))
 ytitle(Health Index, size(small))
 xtitle(week of birth, size(small))
 xline(0)
 scheme(s1color)
 saving("health_week",replace);
