clear all

cd "/Users/kiki/Dropbox/Romania Education/JHR_replication_folder"
use mortality_rate_JHR.dta



*************
* pre-setup *
*************

gen byte leap=((mod(byear,4) == 0 & mod(byear,100) != 0) | mod(byear,400) == 0)

gen int day1=bday if bday<=180
replace day1=bday-365 if bday>185 & leap==0
replace day1=bday-366 if bday>186 & leap==1

**** define day
gen day=byear*1000+bday

**** redfine day1 so cutoff is at 0 (not 1)
replace day1=day1-1

**** define after
gen byte after=(day1>=0)


****************************************** setup ************************************************


************************************
* define treatment discontinuities *
************************************



gen int disc=.

replace disc=41 if (byear==1941 & after==0) | (byear==1942 & after==1) 
replace disc=42 if (byear==1942 & after==0) | (byear==1943 & after==1) 
replace disc=43 if (byear==1943 & after==0) | (byear==1944 & after==1) 
replace disc=44 if (byear==1944 & after==0) | (byear==1945 & after==1) 
replace disc=45 if (byear==1945 & after==0) | (byear==1946 & after==1) 
replace disc=46 if (byear==1946 & after==0) | (byear==1947 & after==1) 
replace disc=47 if (byear==1947 & after==0) | (byear==1948 & after==1) 
replace disc=48 if (byear==1948 & after==0) | (byear==1949 & after==1) 
replace disc=49 if (byear==1949 & after==0) | (byear==1950 & after==1) 
replace disc=50 if (byear==1950 & after==0) | (byear==1951 & after==1) 
replace disc=51 if (byear==1951 & after==0) | (byear==1952 & after==1) 
replace disc=52 if (byear==1952 & after==0) | (byear==1953 & after==1) 
replace disc=53 if (byear==1953 & after==0) | (byear==1954 & after==1) 
replace disc=54 if (byear==1954 & after==0) | (byear==1955 & after==1) 
replace disc=55 if (byear==1955 & after==0) | (byear==1956 & after==1)



gen byte treatment=.

*main treatment years
replace treatment=1 if (disc>=44 & disc<=49)

*control years
replace treatment=0 if (disc>=50 & disc<=52)


*define after*treatment 
gen byte after_treatment=after*treatment

*define separate indicator for control years
gen byte control=1-treatment





*********************
* define day trends *
*********************


***** day trends
gen day2=day1*day1
gen day3=day1*day1*day1
gen day1_after=day1*after
gen day2_after=day2*after
gen day3_after=day3*after

gen day1_treatment=day1*treatment
gen day2_treatment=day2*treatment
gen day3_treatment=day3*treatment

gen day1_treatment_after=day1*treatment*after
gen day2_treatment_after=day2*treatment*after
gen day3_treatment_after=day3*treatment*after


**** discontinuity *****
forvalues disc=44/53 {
   quietly gen byte disc_`disc'=0 if disc!=.
   quietly replace disc_`disc'=1 if disc==`disc'
}




****************************************** regression specifications ************************************************

*create weight variable
gen wij=.


*******************
* define controls *
*******************

global controls1 ""


******************************
* set alternative bandwidths *
******************************

global bandwidths "180"


**************************
* specify relevant discs *
**************************

global disc "disc_44 disc_45 disc_46 disc_47 disc_48 disc_49 disc_50 disc_51 disc_52 disc_53"




*************************************************** 7 day donuts *******************************************************


***********************************
* drop days for donut regressions *
***********************************


drop if (day1>=-7 & day1<=-1) | (day1>=0 & day1<=6) 

**********************
*** loop over vars ***
**********************

foreach var of varlist mort_rate {

*name global variable
global var "`var'"

*create outreg file
xi: reg `var', robust 
outreg2 using AppTable4_mortality, nocons keep($after) se bracket coefastr bdec(3) sdec(3) ctitle("TEST") excel slow(2000) replace



*******************
*** all cohorts ***
*******************

*restrict to treatment and control years

keep if treatment==0 | treatment==1
global restrict1 "treatment==1 | treatment==0" 

*specify trend and after
global trend "day1 day1_after day1_treatment day1_treatment_after" 
global after="after after_treatment"

*reset weights
replace wij=.


*loop across alternative bandwidths
*foreach bw of numlist $bandwidths {
foreach trend in "day1 day1_treatment day1_after day1_treatment_after" "day1 day1_treatment day2 day2_treatment day1_after day1_treatment_after day2_after day2_treatment_after" "day1 day1_treatment day2 day2_treatment day3 day3_treatment day1_after day1_treatment_after day2_after day2_treatment_after day3_after day3_treatment_after" {   

	quietly replace wij = 1 - abs((day1+0.5)/180) 
	quietly replace wij = 0 if abs((day1+0.5)/180) >= 1 
	xi: reg mort_rate after after_treatment `trend' $disc $controls1 [iw=wij]  if abs(day1+0.5)<=180 , robust 
	outreg2 using AppTable4_mortality, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(2000) append
}



}

