
clear all
cd "/Users/kiki/Dropbox/Romania Education/JHR_replication_folder"
use short_census11.dta, replace


*************
* pre-setup *
*************
drop bmonth bday
*leap*
gen byte leap=((mod(byear,4) == 0 & mod(byear,100) != 0) | mod(byear,400) == 0)
gen bmonth=ll
gen bdate=zz

*drop 31st date of months with 30 days
drop if bmonth==4 & bdate==31
drop if bmonth==6 & bdate==31
drop if bmonth==9 & bdate==31
drop if bmonth==11 & bdate==31
drop if bmonth==2 & (bdate==30 | bdate==31) 
drop if bmonth==2 & leap==0 & bdate==29

*keep actual month and day of birth*
quietly gen int bday=.
quietly replace bday=0+bdate if bmonth==1 & leap==1
quietly replace bday=31+bdate if bmonth==2 & leap==1
quietly replace bday=60+bdate if bmonth==3 & leap==1
quietly replace bday=91+bdate if bmonth==4 & leap==1
quietly replace bday=121+bdate if bmonth==5 & leap==1
quietly replace bday=152+bdate if bmonth==6 & leap==1
quietly replace bday=182+bdate if bmonth==7 & leap==1
quietly replace bday=213+bdate if bmonth==8 & leap==1
quietly replace bday=244+bdate if bmonth==9 & leap==1
quietly replace bday=274+bdate if bmonth==10 & leap==1
quietly replace bday=305+bdate if bmonth==11 & leap==1
quietly replace bday=335+bdate if bmonth==12 & leap==1

quietly replace bday=0+bdate if bmonth==1 & leap==0
quietly replace bday=31+bdate if bmonth==2 & leap==0
quietly replace bday=59+bdate if bmonth==3 & leap==0
quietly replace bday=90+bdate if bmonth==4 & leap==0
quietly replace bday=120+bdate if bmonth==5 & leap==0
quietly replace bday=151+bdate if bmonth==6 & leap==0
quietly replace bday=181+bdate if bmonth==7 & leap==0
quietly replace bday=212+bdate if bmonth==8 & leap==0
quietly replace bday=243+bdate if bmonth==9 & leap==0
quietly replace bday=273+bdate if bmonth==10 & leap==0
quietly replace bday=304+bdate if bmonth==11 & leap==0
quietly replace bday=334+bdate if bmonth==12 & leap==0

drop if bday==.
drop if bmonth==.
drop if byear==.



gen int day1=bday if bday<=180
*replace day1=bday-365 if bday>185 
replace day1=bday-365 if bday>185 & leap==0
replace day1=bday-366 if bday>186 & leap==1

**** define day
gen day=byear*1000+bday

**** redfine day1 so cutoff is at 0 (not 1)
replace day1=day1-1

**** define after
gen byte after=(day1>=0)



****************************************** setup ************************************************


************************************
* define treatment discontinuities *
************************************



gen int disc=.

replace disc=41 if (byear==1941 & after==0) | (byear==1942 & after==1) 
replace disc=42 if (byear==1942 & after==0) | (byear==1943 & after==1) 
replace disc=43 if (byear==1943 & after==0) | (byear==1944 & after==1) 
replace disc=44 if (byear==1944 & after==0) | (byear==1945 & after==1) 
replace disc=45 if (byear==1945 & after==0) | (byear==1946 & after==1) 
replace disc=46 if (byear==1946 & after==0) | (byear==1947 & after==1) 
replace disc=47 if (byear==1947 & after==0) | (byear==1948 & after==1) 
replace disc=48 if (byear==1948 & after==0) | (byear==1949 & after==1) 
replace disc=49 if (byear==1949 & after==0) | (byear==1950 & after==1) 
replace disc=50 if (byear==1950 & after==0) | (byear==1951 & after==1) 
replace disc=51 if (byear==1951 & after==0) | (byear==1952 & after==1) 
replace disc=52 if (byear==1952 & after==0) | (byear==1953 & after==1) 
replace disc=53 if (byear==1953 & after==0) | (byear==1954 & after==1) 
replace disc=54 if (byear==1954 & after==0) | (byear==1955 & after==1) 
replace disc=55 if (byear==1955 & after==0) | (byear==1956 & after==1)



gen byte treatment=.

*main treatment years
replace treatment=1 if (disc>=44 & disc<=49)

*old control years
replace treatment=0 if (disc>=50 & disc<=52)



*define after*treatment 
gen byte after_treatment=after*treatment

*define separate indicator for control years
gen byte control=1-treatment



*********************
* define day trends *
*********************


***** day trends

gen day1_after=day1*after
gen day1_treatment=day1*treatment
gen day1_treatment_after=day1*treatment*after


**** discontinuity *****
forvalues disc=44/53 {
   quietly gen byte disc_`disc'=0 if disc!=.
   quietly replace disc_`disc'=1 if disc==`disc'
}




****************************************** regression specifications ************************************************

*create weight variable
gen wij=.


*******************
* define controls *
*******************

global controls1 ""


******************************
* set alternative bandwidths *
******************************

global bandwidths "180"



**************************
* specify relevant discs *
**************************

global disc "disc_44 disc_45 disc_46 disc_47 disc_48 disc_49 disc_50 disc_51 disc_52 disc_53"


*specify trend and after
global trend "day1 day1_after day1_treatment day1_treatment_after" 
global after="after after_treatment"



collapse (mean)  health day1-wij , by (byear bmonth bday)



*************************************************** Table 4 ***************************************************

*set Table 4 outcomes
global outcomes "health" 

*set Table 4 file name
global file "Table4_health" 

*create outreg file
xi: reg health, robust 
outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) ctitle("TEST") excel slow(25000) replace

preserve

****************************
*** Panel A: full sample ***
****************************

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

****************************
*** Panel B: 7-day donut ***
****************************

drop if (day1>=-7 & day1<=-1) | (day1>=0 & day1<=6) 

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}


*****************************
*** Panel C: 14-day donut ***
*****************************

drop if (day1>=-14 & day1<=-1) | (day1>=0 & day1<=13) 

foreach var of varlist $outcomes {
	*reset weights
	replace wij=.
	quietly replace wij = 1 - abs((day1+0.5)/$bw) 
	quietly replace wij = 0 if abs((day1+0.5)/$bw) >= 1 
	*RD regression
	xi: reg `var' $after $trend $disc $controls1 [iw=wij] if abs(day1+0.5)<=$bw , robust 
	outreg2 using $file, nocons keep($after) se bracket coefastr bdec(3) sdec(3) excel slow(25000) append
}

restore

erase "$file.txt"


