clear
set mem 600m
set more off


cd "/Users/kiki/Dropbox/Romania Education/JHR_replication_folder/"

use short_census92.dta


/*************************/
/* generate cohort sizes in 1992 by day and month and year of birth */
/*************************/


gen n=1
drop if bday==.
drop if bmonth==.
drop if byear==.

collapse (sum) n (mean) month, by (bmonth byear bday)

rename n cohort_size

sort bmonth byear bday

save cohort_full_92.dta, replace



/*************************/
/* mortality numbers between 1994 and 2011 by month of birth */
/*************************/


use mortality_1994_2016.dta, clear

*****recode the bday to account for leap years

drop bmonth bday 
quietly gen bmonth=monthb if monthb>=1 & monthb<=12

**** drop if birthday is less than 1 or more than 31
keep if dayb>=1 & dayb<=31

*drop 31st date of months with 30 days
quietly gen int bdate=dayb if dayb<=31
drop if bmonth==4 & bdate==31
drop if bmonth==6 & bdate==31
drop if bmonth==9 & bdate==31
drop if bmonth==11 & bdate==31

gen byte leap=((mod(byear,4) == 0 & mod(byear,100) != 0) | mod(byear,400) == 0)
drop if bmonth==2 & (bdate==30 | bdate==31)
drop if bmonth==2 & leap==0 & bdate==29


*keep actual month and day of birth*
 gen int bday=.
 replace bday=0+dayb if dayb>=1 & dayb<=31 & monthb==1	& leap==1
 replace bday=31+dayb if dayb>=1 & dayb<=31 & monthb==2	& leap==1
 replace bday=60+dayb if dayb>=1 & dayb<=31 & monthb==3	& leap==1
 replace bday=91+dayb if dayb>=1 & dayb<=31 & monthb==4	& leap==1
 replace bday=121+dayb if dayb>=1 & dayb<=31 & monthb==5	& leap==1
 replace bday=152+dayb if dayb>=1 & dayb<=31 & monthb==6	& leap==1
 replace bday=182+dayb if dayb>=1 & dayb<=31 & monthb==7	& leap==1
 replace bday=213+dayb if dayb>=1 & dayb<=31 & monthb==8	& leap==1
 replace bday=244+dayb if dayb>=1 & dayb<=31 & monthb==9	& leap==1
 replace bday=274+dayb if dayb>=1 & dayb<=31 & monthb==10	& leap==1
 replace bday=305+dayb if dayb>=1 & dayb<=31 & monthb==11	& leap==1
 replace bday=335+dayb if dayb>=1 & dayb<=31 & monthb==12	& leap==1
	
	
 replace bday=0+dayb if dayb>=1 & dayb<=31 & monthb==1	& leap==0
 replace bday=31+dayb if dayb>=1 & dayb<=31 & monthb==2	& leap==0
 replace bday=59+dayb if dayb>=1 & dayb<=31 & monthb==3	& leap==0
 replace bday=90+dayb if dayb>=1 & dayb<=31 & monthb==4	& leap==0
 replace bday=120+dayb if dayb>=1 & dayb<=31 & monthb==5	& leap==0
 replace bday=151+dayb if dayb>=1 & dayb<=31 & monthb==6	& leap==0
 replace bday=181+dayb if dayb>=1 & dayb<=31 & monthb==7	& leap==0
 replace bday=212+dayb if dayb>=1 & dayb<=31 & monthb==8	& leap==0
 replace bday=243+dayb if dayb>=1 & dayb<=31 & monthb==9	& leap==0
 replace bday=273+dayb if dayb>=1 & dayb<=31 & monthb==10	& leap==0
 replace bday=304+dayb if dayb>=1 & dayb<=31 & monthb==11	& leap==0
 replace bday=334+dayb if dayb>=1 & dayb<=31 & monthb==12	& leap==0





gen n=1
collapse (sum) n (mean) month, by (bmonth byear bday)
rename n mortality_size
sort bmonth byear bday
save mortality_rate_JHR.dta, replace

merge bmonth byear bday using cohort_full_92.dta
drop if _merge==2
drop _merge
gen mort_rate= mortality_size/cohort_size
save, replace



/*************************/
/* mortality numbers between 1994 and 2011 by day and month of birth AND cause of mortality*/
/*************************/


use mortality_1994_2016.dta

*****recode the bday to account for leap years

drop bmonth bday 
quietly gen bmonth=monthb if monthb>=1 & monthb<=12

**** drop if birthday is less than 1 or more than 31
keep if dayb>=1 & dayb<=31

*drop 31st date of months with 30 days
quietly gen int bdate=dayb if dayb<=31
drop if bmonth==4 & bdate==31
drop if bmonth==6 & bdate==31
drop if bmonth==9 & bdate==31
drop if bmonth==11 & bdate==31

gen byte leap=((mod(byear,4) == 0 & mod(byear,100) != 0) | mod(byear,400) == 0)
drop if bmonth==2 & (bdate==30 | bdate==31)
drop if bmonth==2 & leap==0 & bdate==29


*keep actual month and day of birth*
 gen int bday=.
 replace bday=0+dayb if dayb>=1 & dayb<=31 & monthb==1	& leap==1
 replace bday=31+dayb if dayb>=1 & dayb<=31 & monthb==2	& leap==1
 replace bday=60+dayb if dayb>=1 & dayb<=31 & monthb==3	& leap==1
 replace bday=91+dayb if dayb>=1 & dayb<=31 & monthb==4	& leap==1
 replace bday=121+dayb if dayb>=1 & dayb<=31 & monthb==5	& leap==1
 replace bday=152+dayb if dayb>=1 & dayb<=31 & monthb==6	& leap==1
 replace bday=182+dayb if dayb>=1 & dayb<=31 & monthb==7	& leap==1
 replace bday=213+dayb if dayb>=1 & dayb<=31 & monthb==8	& leap==1
 replace bday=244+dayb if dayb>=1 & dayb<=31 & monthb==9	& leap==1
 replace bday=274+dayb if dayb>=1 & dayb<=31 & monthb==10	& leap==1
 replace bday=305+dayb if dayb>=1 & dayb<=31 & monthb==11	& leap==1
 replace bday=335+dayb if dayb>=1 & dayb<=31 & monthb==12	& leap==1
	
	
 replace bday=0+dayb if dayb>=1 & dayb<=31 & monthb==1	& leap==0
 replace bday=31+dayb if dayb>=1 & dayb<=31 & monthb==2	& leap==0
 replace bday=59+dayb if dayb>=1 & dayb<=31 & monthb==3	& leap==0
 replace bday=90+dayb if dayb>=1 & dayb<=31 & monthb==4	& leap==0
 replace bday=120+dayb if dayb>=1 & dayb<=31 & monthb==5	& leap==0
 replace bday=151+dayb if dayb>=1 & dayb<=31 & monthb==6	& leap==0
 replace bday=181+dayb if dayb>=1 & dayb<=31 & monthb==7	& leap==0
 replace bday=212+dayb if dayb>=1 & dayb<=31 & monthb==8	& leap==0
 replace bday=243+dayb if dayb>=1 & dayb<=31 & monthb==9	& leap==0
 replace bday=273+dayb if dayb>=1 & dayb<=31 & monthb==10	& leap==0
 replace bday=304+dayb if dayb>=1 & dayb<=31 & monthb==11	& leap==0
 replace bday=334+dayb if dayb>=1 & dayb<=31 & monthb==12	& leap==0


gen n=1
collapse (sum) n (mean) month, by (bmonth byear bday cancer circulatory )
rename n mortality_size
sort bmonth byear bday
save mortality_rate_by_cause_death.dta, replace
drop _all

use mortality_1994_2016.dta

*****recode the bday to account for leap years

drop bmonth bday 
quietly gen bmonth=monthb if monthb>=1 & monthb<=12

**** drop if birthday is less than 1 or more than 31
keep if dayb>=1 & dayb<=31

*drop 31st date of months with 30 days
quietly gen int bdate=dayb if dayb<=31
drop if bmonth==4 & bdate==31
drop if bmonth==6 & bdate==31
drop if bmonth==9 & bdate==31
drop if bmonth==11 & bdate==31

gen byte leap=((mod(byear,4) == 0 & mod(byear,100) != 0) | mod(byear,400) == 0)
drop if bmonth==2 & (bdate==30 | bdate==31)
drop if bmonth==2 & leap==0 & bdate==29


*keep actual month and day of birth*
 gen int bday=.
 replace bday=0+dayb if dayb>=1 & dayb<=31 & monthb==1	& leap==1
 replace bday=31+dayb if dayb>=1 & dayb<=31 & monthb==2	& leap==1
 replace bday=60+dayb if dayb>=1 & dayb<=31 & monthb==3	& leap==1
 replace bday=91+dayb if dayb>=1 & dayb<=31 & monthb==4	& leap==1
 replace bday=121+dayb if dayb>=1 & dayb<=31 & monthb==5	& leap==1
 replace bday=152+dayb if dayb>=1 & dayb<=31 & monthb==6	& leap==1
 replace bday=182+dayb if dayb>=1 & dayb<=31 & monthb==7	& leap==1
 replace bday=213+dayb if dayb>=1 & dayb<=31 & monthb==8	& leap==1
 replace bday=244+dayb if dayb>=1 & dayb<=31 & monthb==9	& leap==1
 replace bday=274+dayb if dayb>=1 & dayb<=31 & monthb==10	& leap==1
 replace bday=305+dayb if dayb>=1 & dayb<=31 & monthb==11	& leap==1
 replace bday=335+dayb if dayb>=1 & dayb<=31 & monthb==12	& leap==1
	
	
 replace bday=0+dayb if dayb>=1 & dayb<=31 & monthb==1	& leap==0
 replace bday=31+dayb if dayb>=1 & dayb<=31 & monthb==2	& leap==0
 replace bday=59+dayb if dayb>=1 & dayb<=31 & monthb==3	& leap==0
 replace bday=90+dayb if dayb>=1 & dayb<=31 & monthb==4	& leap==0
 replace bday=120+dayb if dayb>=1 & dayb<=31 & monthb==5	& leap==0
 replace bday=151+dayb if dayb>=1 & dayb<=31 & monthb==6	& leap==0
 replace bday=181+dayb if dayb>=1 & dayb<=31 & monthb==7	& leap==0
 replace bday=212+dayb if dayb>=1 & dayb<=31 & monthb==8	& leap==0
 replace bday=243+dayb if dayb>=1 & dayb<=31 & monthb==9	& leap==0
 replace bday=273+dayb if dayb>=1 & dayb<=31 & monthb==10	& leap==0
 replace bday=304+dayb if dayb>=1 & dayb<=31 & monthb==11	& leap==0
 replace bday=334+dayb if dayb>=1 & dayb<=31 & monthb==12	& leap==0


gen n=1
collapse (sum) n (mean) month, by (bmonth byear bday treatable preventable_external )


rename n mortality_size
append using mortality_rate_by_cause_death.dta

sort bmonth byear bday
save mortality_rate_by_cause_death.dta, replace


merge m:m bmonth byear bday using cohort_full_92.dta



drop if _merge==2
drop _merge
gen mort_rate= mortality_size/cohort_size
save mortality_rate_by_cause_death.dta, replace


